@@ -1,14 +1,10 @@
 use crate::{traits::ApubObject, APUB_JSON_CONTENT_TYPE};
-use activitystreams::chrono::{Duration as ChronoDuration, NaiveDateTime, Utc};
 use anyhow::anyhow;
+use chrono::{Duration as ChronoDuration, NaiveDateTime, Utc};
 use diesel::NotFound;
-use lemmy_utils::{
-  request::{build_user_agent, retry},
-  settings::structs::Settings,
-  LemmyError,
-};
-use once_cell::sync::Lazy;
-use reqwest::{Client, StatusCode};
+use lemmy_utils::{request::retry, settings::structs::Settings, LemmyError};
+use reqwest::StatusCode;
+use reqwest_middleware::ClientWithMiddleware;
 use serde::{Deserialize, Serialize};
 use std::{
   fmt::{Debug, Display, Formatter},
@@ -18,17 +14,6 @@ use std::{
 use tracing::info;
 use url::Url;
 
-/// Maximum number of HTTP requests allowed to handle a single incoming activity (or a single object
-/// fetch through the search). This should be configurable.
-static REQUEST_LIMIT: i32 = 25;
-
-static CLIENT: Lazy<Client> = Lazy::new(|| {
-  Client::builder()
-    .user_agent(build_user_agent(&Settings::get()))
-    .build()
-    .expect("Couldn't build client")
-});
-
 /// We store Url on the heap because it is quite large (88 bytes).
 #[derive(Clone, PartialEq, Serialize, Deserialize, Debug)]
 #[serde(transparent)]
@@ -57,6 +42,7 @@ where
   pub async fn dereference(
     &self,
     data: &<Kind as ApubObject>::DataType,
+    client: &ClientWithMiddleware,
     request_counter: &mut i32,
   ) -> Result<Kind, LemmyError> {
     let db_object = self.dereference_from_db(data).await?;
@@ -75,7 +61,7 @@ where
       if let Some(last_refreshed_at) = object.last_refreshed_at() {
         if should_refetch_object(last_refreshed_at) {
           return self
-            .dereference_from_http(data, request_counter, Some(object))
+            .dereference_from_http(data, client, request_counter, Some(object))
             .await;
         }
       }
@@ -84,7 +70,7 @@ where
     // object not found, need to fetch over http
     else {
       self
-        .dereference_from_http(data, request_counter, None)
+        .dereference_from_http(data, client, request_counter, None)
         .await
     }
   }
@@ -111,6 +97,7 @@ where
   async fn dereference_from_http(
     &self,
     data: &<Kind as ApubObject>::DataType,
+    client: &ClientWithMiddleware,
     request_counter: &mut i32,
     db_object: Option<Kind>,
   ) -> Result<Kind, LemmyError> {
@@ -119,12 +106,12 @@ where
     info!("Fetching remote object {}", self.to_string());
 
     *request_counter += 1;
-    if *request_counter > REQUEST_LIMIT {
-      return Err(LemmyError::from(anyhow!("Request limit reached")));
+    if *request_counter > Settings::get().http_fetch_retry_limit {
+      return Err(LemmyError::from(anyhow!("Request retry limit reached")));
     }
 
     let res = retry(|| {
-      CLIENT
+      client
         .get(self.0.as_str())
         .header("Accept", APUB_JSON_CONTENT_TYPE)
         .timeout(Duration::from_secs(60))
@@ -174,7 +161,7 @@ where
   #[allow(clippy::to_string_in_display)]
   fn fmt(&self, f: &mut Formatter<'_>) -> std::fmt::Result {
     // Use to_string here because Url.display is not useful for us
-    write!(f, "{}", self.0.to_string())
+    write!(f, "{}", self.0)
   }
 }
 
